@@ -10,7 +10,3 @@ def getkey(value, arg):
 @register.filter(name='split')
 def split(value, arg):
     return value.split(arg)
-
-@register.filter(name='cut')
-def cut(value, arg):
-    return value.replace(arg, '')
